from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Types import DataType
from ......Internal.Utilities import trim_str_response
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 6 total commands, 0 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	def get_dselection(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA:DSELection \n
		Snippet: value: str = driver.source.bb.wlad.pconfig.data.get_dselection() \n
		Selects a data list, for the DLIST data source selection. The lists are stored as files with the fixed file extensions *.
		dm_iqd in a directory of the user's choice. The directory applicable to the following commands is defined with the
		command method RsSmw.MassMemory.currentDirectory. To access the files in this directory, you only have to give the file
		name without the path and the file extension. \n
			:return: dselection: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAD:PCONfig:DATA:DSELection?')
		return trim_str_response(response)

	def set_dselection(self, dselection: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA:DSELection \n
		Snippet: driver.source.bb.wlad.pconfig.data.set_dselection(dselection = '1') \n
		Selects a data list, for the DLIST data source selection. The lists are stored as files with the fixed file extensions *.
		dm_iqd in a directory of the user's choice. The directory applicable to the following commands is defined with the
		command method RsSmw.MassMemory.currentDirectory. To access the files in this directory, you only have to give the file
		name without the path and the file extension. \n
			:param dselection: string
		"""
		param = Conversions.value_to_quoted_str(dselection)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAD:PCONfig:DATA:DSELection {param}')

	def get_length(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA:LENGth \n
		Snippet: value: int = driver.source.bb.wlad.pconfig.data.get_length() \n
		Sets the size of the data field in bytes. The data length is related to the number of data symbols that is set with
		method RsSmw.Source.Bb.Wlad.Pconfig.Data.symbols. Whenever the data length changes, the number of data symbols is updated
		and vice versa. \n
			:return: length: integer Range: 1 to 262107
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAD:PCONfig:DATA:LENGth?')
		return Conversions.str_to_int(response)

	def set_length(self, length: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA:LENGth \n
		Snippet: driver.source.bb.wlad.pconfig.data.set_length(length = 1) \n
		Sets the size of the data field in bytes. The data length is related to the number of data symbols that is set with
		method RsSmw.Source.Bb.Wlad.Pconfig.Data.symbols. Whenever the data length changes, the number of data symbols is updated
		and vice versa. \n
			:param length: integer Range: 1 to 262107
		"""
		param = Conversions.decimal_value_to_str(length)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAD:PCONfig:DATA:LENGth {param}')

	# noinspection PyTypeChecker
	class PatternStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Pattern: List[str]: numeric
			- Bitcount: int: integer Range: 1 to 64"""
		__meta_args_list = [
			ArgStruct('Pattern', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: List[str] = None
			self.Bitcount: int = None

	def get_pattern(self) -> PatternStruct:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA:PATTern \n
		Snippet: value: PatternStruct = driver.source.bb.wlad.pconfig.data.get_pattern() \n
		Sets the data pattern if BB:WLAD:PCON:DATA PATT. \n
			:return: structure: for return value, see the help for PatternStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce<HwInstance>:BB:WLAD:PCONfig:DATA:PATTern?', self.__class__.PatternStruct())

	def set_pattern(self, value: PatternStruct) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA:PATTern \n
		Snippet: driver.source.bb.wlad.pconfig.data.set_pattern(value = PatternStruct()) \n
		Sets the data pattern if BB:WLAD:PCON:DATA PATT. \n
			:param value: see the help for PatternStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce<HwInstance>:BB:WLAD:PCONfig:DATA:PATTern', value)

	def get_rate(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA:RATE \n
		Snippet: value: float = driver.source.bb.wlad.pconfig.data.get_rate() \n
		Queries the PPDU data rate. \n
			:return: rate: float Range: 0 to LONG_MAX
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAD:PCONfig:DATA:RATE?')
		return Conversions.str_to_float(response)

	def get_symbols(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA:SYMBols \n
		Snippet: value: int = driver.source.bb.wlad.pconfig.data.get_symbols() \n
		No command help available \n
			:return: symbols: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAD:PCONfig:DATA:SYMBols?')
		return Conversions.str_to_int(response)

	def set_symbols(self, symbols: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA:SYMBols \n
		Snippet: driver.source.bb.wlad.pconfig.data.set_symbols(symbols = 1) \n
		No command help available \n
			:param symbols: No help available
		"""
		param = Conversions.decimal_value_to_str(symbols)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAD:PCONfig:DATA:SYMBols {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.WlannDataSource:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA \n
		Snippet: value: enums.WlannDataSource = driver.source.bb.wlad.pconfig.data.get_value() \n
		Sets the data source. \n
			:return: data: ZERO| ONE| PATTern| PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt| AMPDU
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAD:PCONfig:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.WlannDataSource)

	def set_value(self, data: enums.WlannDataSource) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:DATA \n
		Snippet: driver.source.bb.wlad.pconfig.data.set_value(data = enums.WlannDataSource.AMPDU) \n
		Sets the data source. \n
			:param data: ZERO| ONE| PATTern| PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt| AMPDU
		"""
		param = Conversions.enum_scalar_to_str(data, enums.WlannDataSource)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAD:PCONfig:DATA {param}')



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Table:
	"""Table commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("table", core, parent)

	def set(self, table: enums.TdscdmaEnhHsTbsTableUp, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:ENH:DCH:HSUPA:TBS:TABLe \n
		Snippet: driver.source.bb.tdscdma.up.cell.enh.dch.hsupa.tbs.table.set(table = enums.TdscdmaEnhHsTbsTableUp.C1TO2, cell = repcap.Cell.Default) \n
		Sets the transport block size table, according to the specification 3GPP TS 25.321, annex BC. \n
			:param table: C1TO2| C3TO6
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')"""
		param = Conversions.enum_scalar_to_str(table, enums.TdscdmaEnhHsTbsTableUp)
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:ENH:DCH:HSUPA:TBS:TABLe {param}')

	# noinspection PyTypeChecker
	def get(self, cell=repcap.Cell.Default) -> enums.TdscdmaEnhHsTbsTableUp:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:ENH:DCH:HSUPA:TBS:TABLe \n
		Snippet: value: enums.TdscdmaEnhHsTbsTableUp = driver.source.bb.tdscdma.up.cell.enh.dch.hsupa.tbs.table.get(cell = repcap.Cell.Default) \n
		Sets the transport block size table, according to the specification 3GPP TS 25.321, annex BC. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: table: C1TO2| C3TO6"""
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:ENH:DCH:HSUPA:TBS:TABLe?')
		return Conversions.str_to_scalar_enum(response, enums.TdscdmaEnhHsTbsTableUp)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 4 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	@property
	def dselect(self):
		"""dselect commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dselect'):
			from .Dselect import Dselect
			self._dselect = Dselect(self._core, self._base)
		return self._dselect

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import Pattern
			self._pattern = Pattern(self._core, self._base)
		return self._pattern

	@property
	def rate(self):
		"""rate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rate'):
			from .Rate import Rate
			self._rate = Rate(self._core, self._base)
		return self._rate

	def set(self, data: enums.DataSourceA, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:DATA \n
		Snippet: driver.source.bb.c2K.bstation.cgroup.coffset.data.set(data = enums.DataSourceA.DLISt, baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command selects the data source for the specified channel. For the traffic channels, this value is specific for the
		selected radio configuration. The data source for the power control bits is selected with the command method RsSmw.Source.
		Bb.C2K.Bstation.Cgroup.Coffset.Tpc.Data.set. \n
			:param data: ZERO| ONE| PATTern| PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt PNxx The pseudo-random sequence generator is used as the data source. Different random sequence lengths can be selected. DLISt A data list is used. The data list is selected with the command :BB:C2K:BSTn:CGRoupn:COFFsetn:DATA:DSEL. ZERO | ONE Internal 0 and 1 data is used. PATTern Internal data is used. The bit pattern for the data is defined by the command :BB:C2K:BST:CGRoup:COFFset:DATA:PATT.
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')"""
		param = Conversions.enum_scalar_to_str(data, enums.DataSourceA)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._base.get_repcap_cmd_value(offset, repcap.Offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:DATA {param}')

	# noinspection PyTypeChecker
	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> enums.DataSourceA:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:DATA \n
		Snippet: value: enums.DataSourceA = driver.source.bb.c2K.bstation.cgroup.coffset.data.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command selects the data source for the specified channel. For the traffic channels, this value is specific for the
		selected radio configuration. The data source for the power control bits is selected with the command method RsSmw.Source.
		Bb.C2K.Bstation.Cgroup.Coffset.Tpc.Data.set. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: data: ZERO| ONE| PATTern| PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt PNxx The pseudo-random sequence generator is used as the data source. Different random sequence lengths can be selected. DLISt A data list is used. The data list is selected with the command :BB:C2K:BSTn:CGRoupn:COFFsetn:DATA:DSEL. ZERO | ONE Internal 0 and 1 data is used. PATTern Internal data is used. The bit pattern for the data is defined by the command :BB:C2K:BST:CGRoup:COFFset:DATA:PATT."""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._base.get_repcap_cmd_value(offset, repcap.Offset)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceA)

	def clone(self) -> 'Data':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Data(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SubSize:
	"""SubSize commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("subSize", core, parent)

	def set(self, sub_channel_size: enums.EutraSlV2xSubchannelSize, userEquipment=repcap.UserEquipment.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:V2X:SUBSize \n
		Snippet: driver.source.bb.eutra.uplink.ue.sl.v2X.subSize.set(sub_channel_size = enums.EutraSlV2xSubchannelSize._10, userEquipment = repcap.UserEquipment.Default) \n
		Sets the number of resource blocks the subchannel spans. \n
			:param sub_channel_size: 4| 5| 6| 8| 9| 10| 12| 15| 16| 18| 20| 25| 30| 48| 50| 72| 96| 75| 100| 32
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')"""
		param = Conversions.enum_scalar_to_str(sub_channel_size, enums.EutraSlV2xSubchannelSize)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:SL:V2X:SUBSize {param}')

	# noinspection PyTypeChecker
	def get(self, userEquipment=repcap.UserEquipment.Default) -> enums.EutraSlV2xSubchannelSize:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:V2X:SUBSize \n
		Snippet: value: enums.EutraSlV2xSubchannelSize = driver.source.bb.eutra.uplink.ue.sl.v2X.subSize.get(userEquipment = repcap.UserEquipment.Default) \n
		Sets the number of resource blocks the subchannel spans. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:return: sub_channel_size: 4| 5| 6| 8| 9| 10| 12| 15| 16| 18| 20| 25| 30| 48| 50| 72| 96| 75| 100| 32"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:SL:V2X:SUBSize?')
		return Conversions.str_to_scalar_enum(response, enums.EutraSlV2xSubchannelSize)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, mode: int, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[CELL<CCIDX>]:[SUBF<ST0>]:ALLoc<CH0>:PUSCh:FHOP:MODE \n
		Snippet: driver.source.bb.eutra.uplink.cell.subf.alloc.pusch.fhop.mode.set(mode = 1, cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		No command help available \n
			:param mode: No help available
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')"""
		param = Conversions.decimal_value_to_str(mode)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:FHOP:MODE {param}')

	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[CELL<CCIDX>]:[SUBF<ST0>]:ALLoc<CH0>:PUSCh:FHOP:MODE \n
		Snippet: value: int = driver.source.bb.eutra.uplink.cell.subf.alloc.pusch.fhop.mode.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		No command help available \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: mode: No help available"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:FHOP:MODE?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class S120K:
	"""S120K commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("s120K", core, parent)

	def get_acrl(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:POWer:S120K:ACRL \n
		Snippet: value: float = driver.source.bb.nr5G.output.power.s120K.get_acrl() \n
		Queries the bandwidths/numerologies with their power levels. \n
			:return: act_pow_rel_lvl_pbw: float Range: -80 to 10
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:OUTPut:POWer:S120K:ACRL?')
		return Conversions.str_to_float(response)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class System:
	"""System commands group definition. 188 total commands, 34 Sub-groups, 30 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("system", core, parent)

	@property
	def beeper(self):
		"""beeper commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_beeper'):
			from .Beeper import Beeper
			self._beeper = Beeper(self._core, self._base)
		return self._beeper

	@property
	def bios(self):
		"""bios commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bios'):
			from .Bios import Bios
			self._bios = Bios(self._core, self._base)
		return self._bios

	@property
	def communicate(self):
		"""communicate commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_communicate'):
			from .Communicate import Communicate
			self._communicate = Communicate(self._core, self._base)
		return self._communicate

	@property
	def date(self):
		"""date commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_date'):
			from .Date import Date
			self._date = Date(self._core, self._base)
		return self._date

	@property
	def device(self):
		"""device commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_device'):
			from .Device import Device
			self._device = Device(self._core, self._base)
		return self._device

	@property
	def dexchange(self):
		"""dexchange commands group. 3 Sub-classes, 5 commands."""
		if not hasattr(self, '_dexchange'):
			from .Dexchange import Dexchange
			self._dexchange = Dexchange(self._core, self._base)
		return self._dexchange

	@property
	def deviceFootprint(self):
		"""deviceFootprint commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_deviceFootprint'):
			from .DeviceFootprint import DeviceFootprint
			self._deviceFootprint = DeviceFootprint(self._core, self._base)
		return self._deviceFootprint

	@property
	def error(self):
		"""error commands group. 2 Sub-classes, 5 commands."""
		if not hasattr(self, '_error'):
			from .Error import Error
			self._error = Error(self._core, self._base)
		return self._error

	@property
	def fpFpga(self):
		"""fpFpga commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fpFpga'):
			from .FpFpga import FpFpga
			self._fpFpga = FpFpga(self._core, self._base)
		return self._fpFpga

	@property
	def fpreset(self):
		"""fpreset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fpreset'):
			from .Fpreset import Fpreset
			self._fpreset = Fpreset(self._core, self._base)
		return self._fpreset

	@property
	def generic(self):
		"""generic commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_generic'):
			from .Generic import Generic
			self._generic = Generic(self._core, self._base)
		return self._generic

	@property
	def help(self):
		"""help commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_help'):
			from .Help import Help
			self._help = Help(self._core, self._base)
		return self._help

	@property
	def identification(self):
		"""identification commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_identification'):
			from .Identification import Identification
			self._identification = Identification(self._core, self._base)
		return self._identification

	@property
	def information(self):
		"""information commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_information'):
			from .Information import Information
			self._information = Information(self._core, self._base)
		return self._information

	@property
	def linux(self):
		"""linux commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_linux'):
			from .Linux import Linux
			self._linux = Linux(self._core, self._base)
		return self._linux

	@property
	def lock(self):
		"""lock commands group. 5 Sub-classes, 1 commands."""
		if not hasattr(self, '_lock'):
			from .Lock import Lock
			self._lock = Lock(self._core, self._base)
		return self._lock

	@property
	def massMemory(self):
		"""massMemory commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_massMemory'):
			from .MassMemory import MassMemory
			self._massMemory = MassMemory(self._core, self._base)
		return self._massMemory

	@property
	def ntp(self):
		"""ntp commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ntp'):
			from .Ntp import Ntp
			self._ntp = Ntp(self._core, self._base)
		return self._ntp

	@property
	def option(self):
		"""option commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_option'):
			from .Option import Option
			self._option = Option(self._core, self._base)
		return self._option

	@property
	def package(self):
		"""package commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_package'):
			from .Package import Package
			self._package = Package(self._core, self._base)
		return self._package

	@property
	def pciFpga(self):
		"""pciFpga commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pciFpga'):
			from .PciFpga import PciFpga
			self._pciFpga = PciFpga(self._core, self._base)
		return self._pciFpga

	@property
	def profiling(self):
		"""profiling commands group. 5 Sub-classes, 1 commands."""
		if not hasattr(self, '_profiling'):
			from .Profiling import Profiling
			self._profiling = Profiling(self._core, self._base)
		return self._profiling

	@property
	def protect(self):
		"""protect commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_protect'):
			from .Protect import Protect
			self._protect = Protect(self._core, self._base)
		return self._protect

	@property
	def reboot(self):
		"""reboot commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_reboot'):
			from .Reboot import Reboot
			self._reboot = Reboot(self._core, self._base)
		return self._reboot

	@property
	def restart(self):
		"""restart commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_restart'):
			from .Restart import Restart
			self._restart = Restart(self._core, self._base)
		return self._restart

	@property
	def security(self):
		"""security commands group. 6 Sub-classes, 1 commands."""
		if not hasattr(self, '_security'):
			from .Security import Security
			self._security = Security(self._core, self._base)
		return self._security

	@property
	def shutdown(self):
		"""shutdown commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_shutdown'):
			from .Shutdown import Shutdown
			self._shutdown = Shutdown(self._core, self._base)
		return self._shutdown

	@property
	def specification(self):
		"""specification commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_specification'):
			from .Specification import Specification
			self._specification = Specification(self._core, self._base)
		return self._specification

	@property
	def srData(self):
		"""srData commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_srData'):
			from .SrData import SrData
			self._srData = SrData(self._core, self._base)
		return self._srData

	@property
	def srexec(self):
		"""srexec commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srexec'):
			from .Srexec import Srexec
			self._srexec = Srexec(self._core, self._base)
		return self._srexec

	@property
	def srtime(self):
		"""srtime commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_srtime'):
			from .Srtime import Srtime
			self._srtime = Srtime(self._core, self._base)
		return self._srtime

	@property
	def startup(self):
		"""startup commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_startup'):
			from .Startup import Startup
			self._startup = Startup(self._core, self._base)
		return self._startup

	@property
	def time(self):
		"""time commands group. 3 Sub-classes, 3 commands."""
		if not hasattr(self, '_time'):
			from .Time import Time
			self._time = Time(self._core, self._base)
		return self._time

	@property
	def undo(self):
		"""undo commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_undo'):
			from .Undo import Undo
			self._undo = Undo(self._core, self._base)
		return self._undo

	def set_crash(self, test_scpi_generic: float) -> None:
		"""SCPI: SYSTem:CRASh \n
		Snippet: driver.system.set_crash(test_scpi_generic = 1.0) \n
		No command help available \n
			:param test_scpi_generic: No help available
		"""
		param = Conversions.decimal_value_to_str(test_scpi_generic)
		self._core.io.write(f'SYSTem:CRASh {param}')

	def get_dfpr(self) -> str:
		"""SCPI: SYSTem:DFPR \n
		Snippet: value: str = driver.system.get_dfpr() \n
		Queries the device footprint of the instrument. The retrieved information is in machine-readable form suitable for
		automatic further processing. If you are obtaining technical support as described in 'Collecting Information for
		Technical Support', this information is automatically retrieved and is part of the created *.tar.gz support file. \n
			:return: device_footprint: string Information on the instrument type, device identification and details on the installed FW version, hardware and software options.
		"""
		response = self._core.io.query_str('SYSTem:DFPR?')
		return trim_str_response(response)

	def get_did(self) -> str:
		"""SCPI: SYSTem:DID \n
		Snippet: value: str = driver.system.get_did() \n
		No command help available \n
			:return: pseudo_string: No help available
		"""
		response = self._core.io.query_str('SYSTem:DID?')
		return trim_str_response(response)

	def get_dlock(self) -> bool:
		"""SCPI: SYSTem:DLOCk \n
		Snippet: value: bool = driver.system.get_dlock() \n
		Disables the manual operation via the display, including the front panel keyboard of the instrument and the LOCAL key. \n
			:return: disp_lock_stat: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SYSTem:DLOCk?')
		return Conversions.str_to_bool(response)

	def set_dlock(self, disp_lock_stat: bool) -> None:
		"""SCPI: SYSTem:DLOCk \n
		Snippet: driver.system.set_dlock(disp_lock_stat = False) \n
		Disables the manual operation via the display, including the front panel keyboard of the instrument and the LOCAL key. \n
			:param disp_lock_stat: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(disp_lock_stat)
		self._core.io.write(f'SYSTem:DLOCk {param}')

	def set_import_py(self, filename: str) -> None:
		"""SCPI: SYSTem:IMPort \n
		Snippet: driver.system.set_import_py(filename = '1') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SYSTem:IMPort {param}')

	def get_iresponse(self) -> str:
		"""SCPI: SYSTem:IRESponse \n
		Snippet: value: str = driver.system.get_iresponse() \n
		Defines the user defined identification string for *IDN. Note: While working in an emulation mode, the instrument's
		specific command set is disabled, i.e. the SCPI command method RsSmw.System.iresponse is discarded. \n
			:return: idn_response: string
		"""
		response = self._core.io.query_str('SYSTem:IRESponse?')
		return trim_str_response(response)

	def set_iresponse(self, idn_response: str) -> None:
		"""SCPI: SYSTem:IRESponse \n
		Snippet: driver.system.set_iresponse(idn_response = '1') \n
		Defines the user defined identification string for *IDN. Note: While working in an emulation mode, the instrument's
		specific command set is disabled, i.e. the SCPI command method RsSmw.System.iresponse is discarded. \n
			:param idn_response: string
		"""
		param = Conversions.value_to_quoted_str(idn_response)
		self._core.io.write(f'SYSTem:IRESponse {param}')

	def get_klock(self) -> bool:
		"""SCPI: SYSTem:KLOCk \n
		Snippet: value: bool = driver.system.get_klock() \n
		Disables the front panel keyboard of the instrument including the LOCAL key. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SYSTem:KLOCk?')
		return Conversions.str_to_bool(response)

	def set_klock(self, state: bool) -> None:
		"""SCPI: SYSTem:KLOCk \n
		Snippet: driver.system.set_klock(state = False) \n
		Disables the front panel keyboard of the instrument including the LOCAL key. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SYSTem:KLOCk {param}')

	def get_language(self) -> str:
		"""SCPI: SYSTem:LANGuage \n
		Snippet: value: str = driver.system.get_language() \n
		Sets the remote control command set. \n
			:return: language: string
		"""
		response = self._core.io.query_str('SYSTem:LANGuage?')
		return trim_str_response(response)

	def set_language(self, language: str) -> None:
		"""SCPI: SYSTem:LANGuage \n
		Snippet: driver.system.set_language(language = '1') \n
		Sets the remote control command set. \n
			:param language: string
		"""
		param = Conversions.value_to_quoted_str(language)
		self._core.io.write(f'SYSTem:LANGuage {param}')

	def get_ninformation(self) -> str:
		"""SCPI: SYSTem:NINFormation \n
		Snippet: value: str = driver.system.get_ninformation() \n
		Queries the oldest information message ('Error History > Level > Info') in the error/event queue. \n
			:return: next_info: string
		"""
		response = self._core.io.query_str('SYSTem:NINFormation?')
		return trim_str_response(response)

	def get_oresponse(self) -> str:
		"""SCPI: SYSTem:ORESponse \n
		Snippet: value: str = driver.system.get_oresponse() \n
		Defines the user defined response string for *OPT. Note: While working in an emulation mode, the instrument's specific
		command set is disabled, i.e. the SCPI command method RsSmw.System.oresponse is discarded. \n
			:return: oresponse: string
		"""
		response = self._core.io.query_str('SYSTem:ORESponse?')
		return trim_str_response(response)

	def set_oresponse(self, oresponse: str) -> None:
		"""SCPI: SYSTem:ORESponse \n
		Snippet: driver.system.set_oresponse(oresponse = '1') \n
		Defines the user defined response string for *OPT. Note: While working in an emulation mode, the instrument's specific
		command set is disabled, i.e. the SCPI command method RsSmw.System.oresponse is discarded. \n
			:param oresponse: string
		"""
		param = Conversions.value_to_quoted_str(oresponse)
		self._core.io.write(f'SYSTem:ORESponse {param}')

	def get_osystem(self) -> str:
		"""SCPI: SYSTem:OSYStem \n
		Snippet: value: str = driver.system.get_osystem() \n
		Queries the operating system of the instrument. \n
			:return: oper_system: string
		"""
		response = self._core.io.query_str('SYSTem:OSYStem?')
		return trim_str_response(response)

	def preset(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:PRESet \n
		Snippet: driver.system.preset(pseudo_string = '1') \n
			INTRO_CMD_HELP: Triggers an instrument reset. It has the same effect as: \n
			- The [PRESET] key. However, the command does not close open GUI dialogs like the key does.
			- The *RST command
		For an overview of the settings affected by the preset function, see Table 'Key parameters affected by preset and
		factory preset' \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:PRESet {param}')

	def preset_all(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:PRESet:ALL \n
		Snippet: driver.system.preset_all(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:PRESet:ALL {param}')

	def preset_base(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:PRESet:BASE \n
		Snippet: driver.system.preset_base(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:PRESet:BASE {param}')

	def recall(self, path_name: str) -> None:
		"""SCPI: SYSTem:RCL \n
		Snippet: driver.system.recall(path_name = '1') \n
		Loads a file with previously saved R&S SMW settings. Loads the selected file with previously saved R&S SMW settings from
		the default or the specified directory. Loaded are files with extension *.savrcltxt. \n
			:param path_name: string
		"""
		param = Conversions.value_to_quoted_str(path_name)
		self._core.io.write(f'SYSTem:RCL {param}')

	def reset(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:RESet \n
		Snippet: driver.system.reset(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:RESet {param}')

	def reset_all(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:RESet:ALL \n
		Snippet: driver.system.reset_all(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:RESet:ALL {param}')

	def reset_base(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:RESet:BASE \n
		Snippet: driver.system.reset_base(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:RESet:BASE {param}')

	def save(self, path_name: str) -> None:
		"""SCPI: SYSTem:SAV \n
		Snippet: driver.system.save(path_name = '1') \n
		Saves the current R&S SMW settings into a file with defined filename and into a specified directory. The file extension
		(*.savrcltxt) is assigned automatically. \n
			:param path_name: string
		"""
		param = Conversions.value_to_quoted_str(path_name)
		self._core.io.write(f'SYSTem:SAV {param}')

	def get_simulation(self) -> bool:
		"""SCPI: SYSTem:SIMulation \n
		Snippet: value: bool = driver.system.get_simulation() \n
		No command help available \n
			:return: status: No help available
		"""
		response = self._core.io.query_str('SYSTem:SIMulation?')
		return Conversions.str_to_bool(response)

	def get_sr_cat(self) -> List[str]:
		"""SCPI: SYSTem:SRCat \n
		Snippet: value: List[str] = driver.system.get_sr_cat() \n
		No command help available \n
			:return: catalog: No help available
		"""
		response = self._core.io.query_str('SYSTem:SRCat?')
		return Conversions.str_to_str_list(response)

	def set_srestore(self, data_set: int) -> None:
		"""SCPI: SYSTem:SREStore \n
		Snippet: driver.system.set_srestore(data_set = 1) \n
		No command help available \n
			:param data_set: No help available
		"""
		param = Conversions.decimal_value_to_str(data_set)
		self._core.io.write(f'SYSTem:SREStore {param}')

	# noinspection PyTypeChecker
	def get_sr_mode(self) -> enums.RecScpiCmdMode:
		"""SCPI: SYSTem:SRMode \n
		Snippet: value: enums.RecScpiCmdMode = driver.system.get_sr_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('SYSTem:SRMode?')
		return Conversions.str_to_scalar_enum(response, enums.RecScpiCmdMode)

	def set_sr_mode(self, mode: enums.RecScpiCmdMode) -> None:
		"""SCPI: SYSTem:SRMode \n
		Snippet: driver.system.set_sr_mode(mode = enums.RecScpiCmdMode.AUTO) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.RecScpiCmdMode)
		self._core.io.write(f'SYSTem:SRMode {param}')

	def get_sr_sel(self) -> str:
		"""SCPI: SYSTem:SRSel \n
		Snippet: value: str = driver.system.get_sr_sel() \n
		No command help available \n
			:return: filename: No help available
		"""
		response = self._core.io.query_str('SYSTem:SRSel?')
		return trim_str_response(response)

	def set_sr_sel(self, filename: str) -> None:
		"""SCPI: SYSTem:SRSel \n
		Snippet: driver.system.set_sr_sel(filename = '1') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SYSTem:SRSel {param}')

	def set_ssave(self, data_set: int) -> None:
		"""SCPI: SYSTem:SSAVe \n
		Snippet: driver.system.set_ssave(data_set = 1) \n
		No command help available \n
			:param data_set: No help available
		"""
		param = Conversions.decimal_value_to_str(data_set)
		self._core.io.write(f'SYSTem:SSAVe {param}')

	def get_tzone(self) -> str:
		"""SCPI: SYSTem:TZONe \n
		Snippet: value: str = driver.system.get_tzone() \n
		No command help available \n
			:return: pseudo_string: No help available
		"""
		response = self._core.io.query_str('SYSTem:TZONe?')
		return trim_str_response(response)

	def set_tzone(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:TZONe \n
		Snippet: driver.system.set_tzone(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:TZONe {param}')

	# noinspection PyTypeChecker
	def get_ulock(self) -> enums.DispKeybLockMode:
		"""SCPI: SYSTem:ULOCk \n
		Snippet: value: enums.DispKeybLockMode = driver.system.get_ulock() \n
		Locks or unlocks the user interface of the instrument. \n
			:return: mode: ENABled| DONLy| DISabled| TOFF| VNConly ENABled Unlocks the display, the touchscreen and all controls for the manual operation. DONLy Locks the touchscreen and controls for the manual operation of the instrument. The display shows the current settings. VNConly Locks the touchscreen and controls for the manual operation, and enables remote operation over VNC. The display shows the current settings. TOFF Locks the touchscreen for the manual operation of the instrument. The display shows the current settings. DISabled Locks the display, the touchscreen and all controls for the manual operation.
		"""
		response = self._core.io.query_str('SYSTem:ULOCk?')
		return Conversions.str_to_scalar_enum(response, enums.DispKeybLockMode)

	def set_ulock(self, mode: enums.DispKeybLockMode) -> None:
		"""SCPI: SYSTem:ULOCk \n
		Snippet: driver.system.set_ulock(mode = enums.DispKeybLockMode.DISabled) \n
		Locks or unlocks the user interface of the instrument. \n
			:param mode: ENABled| DONLy| DISabled| TOFF| VNConly ENABled Unlocks the display, the touchscreen and all controls for the manual operation. DONLy Locks the touchscreen and controls for the manual operation of the instrument. The display shows the current settings. VNConly Locks the touchscreen and controls for the manual operation, and enables remote operation over VNC. The display shows the current settings. TOFF Locks the touchscreen for the manual operation of the instrument. The display shows the current settings. DISabled Locks the display, the touchscreen and all controls for the manual operation.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.DispKeybLockMode)
		self._core.io.write(f'SYSTem:ULOCk {param}')

	def get_up_time(self) -> str:
		"""SCPI: SYSTem:UPTime \n
		Snippet: value: str = driver.system.get_up_time() \n
		Queries the up time of the operating system. \n
			:return: up_time: 'ddd.hh:mm:ss'
		"""
		response = self._core.io.query_str('SYSTem:UPTime?')
		return trim_str_response(response)

	def get_version(self) -> str:
		"""SCPI: SYSTem:VERSion \n
		Snippet: value: str = driver.system.get_version() \n
		Queries the SCPI version the instrument's command set complies with. \n
			:return: version: string
		"""
		response = self._core.io.query_str('SYSTem:VERSion?')
		return trim_str_response(response)

	def set_wait(self, time_ms: int) -> None:
		"""SCPI: SYSTem:WAIT \n
		Snippet: driver.system.set_wait(time_ms = 1) \n
		Delays the execution of the subsequent remote command by the specified time. This function is useful, for example to
		execute an SCPI sequence automatically but with a defined time delay between some commands. See 'How to Assign Actions to
		the [USER] Key'. \n
			:param time_ms: integer Wait time in ms Range: 0 to 10000
		"""
		param = Conversions.decimal_value_to_str(time_ms)
		self._core.io.write(f'SYSTem:WAIT {param}')

	def clone(self) -> 'System':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = System(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("file", core, parent)

	def get_data(self) -> List[float]:
		"""SCPI: [SOURce<HW>]:IQ:DOHerty:LRF:FILE:DATA \n
		Snippet: value: List[float] = driver.source.iq.doherty.lrf.file.get_data() \n
		No command help available \n
			:return: dpd_rf_am_table_data: No help available
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce<HwInstance>:IQ:DOHerty:LRF:FILE:DATA?')
		return response

	def get_value(self) -> str:
		"""SCPI: [SOURce<HW>]:IQ:DOHerty:LRF:FILE \n
		Snippet: value: str = driver.source.iq.doherty.lrf.file.get_value() \n
		No command help available \n
			:return: filename: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:DOHerty:LRF:FILE?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Gps:
	"""Gps commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gps", core, parent)

	def get_active(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SELection:GPS:ACTive \n
		Snippet: value: int = driver.source.bb.gnss.sv.selection.gps.get_active() \n
		Queries the number of active satellites per GNSS system that are currently part of the satellite's constellation. \n
			:return: active_svs: integer Range: 0 to 24
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:SELection:GPS:ACTive?')
		return Conversions.str_to_int(response)

	def get_available(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SELection:GPS:AVAilable \n
		Snippet: value: int = driver.source.bb.gnss.sv.selection.gps.get_available() \n
		Queries the number of available satellites per GNSS system. \n
			:return: available_svs: integer Range: 0 to 40
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:SELection:GPS:AVAilable?')
		return Conversions.str_to_int(response)

	def get_max(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SELection:GPS:MAX \n
		Snippet: value: int = driver.source.bb.gnss.sv.selection.gps.get_max() \n
		Sets the minimum and maximum number of satellites per GNSS system that can be included in the satellite constellation. \n
			:return: maximum_svs: integer Range: 0 to 24
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:SELection:GPS:MAX?')
		return Conversions.str_to_int(response)

	def set_max(self, maximum_svs: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SELection:GPS:MAX \n
		Snippet: driver.source.bb.gnss.sv.selection.gps.set_max(maximum_svs = 1) \n
		Sets the minimum and maximum number of satellites per GNSS system that can be included in the satellite constellation. \n
			:param maximum_svs: integer Range: 0 to 24
		"""
		param = Conversions.decimal_value_to_str(maximum_svs)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:SELection:GPS:MAX {param}')

	def get_min(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SELection:GPS:MIN \n
		Snippet: value: int = driver.source.bb.gnss.sv.selection.gps.get_min() \n
		Sets the minimum and maximum number of satellites per GNSS system that can be included in the satellite constellation. \n
			:return: minimum_svs: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:SELection:GPS:MIN?')
		return Conversions.str_to_int(response)

	def set_min(self, minimum_svs: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SELection:GPS:MIN \n
		Snippet: driver.source.bb.gnss.sv.selection.gps.set_min(minimum_svs = 1) \n
		Sets the minimum and maximum number of satellites per GNSS system that can be included in the satellite constellation. \n
			:param minimum_svs: integer Range: 0 to 24
		"""
		param = Conversions.decimal_value_to_str(minimum_svs)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:SELection:GPS:MIN {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ssp:
	"""Ssp commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ssp", core, parent)

	def set(self, search_space: enums.EutraSearchSpaceNbiot, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:DCI:ALLoc<CH0>:SSP \n
		Snippet: driver.source.bb.eutra.downlink.niot.dci.alloc.ssp.set(search_space = enums.EutraSearchSpaceNbiot.T1CM, allocationNull = repcap.AllocationNull.Default) \n
		Sets the search space for the selected DCI. \n
			:param search_space: UE| T1CM| T2CM
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')"""
		param = Conversions.enum_scalar_to_str(search_space, enums.EutraSearchSpaceNbiot)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:DCI:ALLoc{allocationNull_cmd_val}:SSP {param}')

	# noinspection PyTypeChecker
	def get(self, allocationNull=repcap.AllocationNull.Default) -> enums.EutraSearchSpaceNbiot:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:DCI:ALLoc<CH0>:SSP \n
		Snippet: value: enums.EutraSearchSpaceNbiot = driver.source.bb.eutra.downlink.niot.dci.alloc.ssp.get(allocationNull = repcap.AllocationNull.Default) \n
		Sets the search space for the selected DCI. \n
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: search_space: UE| T1CM| T2CM"""
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:DCI:ALLoc{allocationNull_cmd_val}:SSP?')
		return Conversions.str_to_scalar_enum(response, enums.EutraSearchSpaceNbiot)



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import enums
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DlPcrs:
	"""DlPcrs commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dlPcrs", core, parent)

	def set(self, dci_dl_pcrs: enums.V5GdCiDlPcrs, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:[SUBF<ST0>]:ENCC:XPDCch:EXTC:ITEM<CH0>:DCIConf:DLPCrs \n
		Snippet: driver.source.bb.v5G.downlink.subf.encc.xpdcch.extc.item.dciConf.dlPcrs.set(dci_dl_pcrs = enums.V5GdCiDlPcrs.AP60, subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Sets the DCI format field DL PCRS to specify antenna ports used by PCRS signal. \n
			:param dci_dl_pcrs: NONE| AP60| AP61| AP6061 No PCRS, PCRS on AP 60, 61, or APs 60-61
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')"""
		param = Conversions.enum_scalar_to_str(dci_dl_pcrs, enums.V5GdCiDlPcrs)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._base.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:SUBF{subframeNull_cmd_val}:ENCC:XPDCch:EXTC:ITEM{itemNull_cmd_val}:DCIConf:DLPCrs {param}')

	# noinspection PyTypeChecker
	def get(self, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> enums.V5GdCiDlPcrs:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:[SUBF<ST0>]:ENCC:XPDCch:EXTC:ITEM<CH0>:DCIConf:DLPCrs \n
		Snippet: value: enums.V5GdCiDlPcrs = driver.source.bb.v5G.downlink.subf.encc.xpdcch.extc.item.dciConf.dlPcrs.get(subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Sets the DCI format field DL PCRS to specify antenna ports used by PCRS signal. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')
			:return: dci_dl_pcrs: NONE| AP60| AP61| AP6061 No PCRS, PCRS on AP 60, 61, or APs 60-61"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._base.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:DL:SUBF{subframeNull_cmd_val}:ENCC:XPDCch:EXTC:ITEM{itemNull_cmd_val}:DCIConf:DLPCrs?')
		return Conversions.str_to_scalar_enum(response, enums.V5GdCiDlPcrs)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Uplink:
	"""Uplink commands group definition. 12 total commands, 3 Sub-groups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("uplink", core, parent)

	@property
	def dall(self):
		"""dall commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dall'):
			from .Dall import Dall
			self._dall = Dall(self._core, self._base)
		return self._dall

	@property
	def eall(self):
		"""eall commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_eall'):
			from .Eall import Eall
			self._eall = Eall(self._core, self._base)
		return self._eall

	@property
	def logPoint(self):
		"""logPoint commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_logPoint'):
			from .LogPoint import LogPoint
			self._logPoint = LogPoint(self._core, self._base)
		return self._logPoint

	def get_eu_logging(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:EULogging \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.uplink.get_eu_logging() \n
		Enables the generation of a logfile with extended information regarding the DCI/UCI mapping. \n
			:return: ext_uci_log: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:EULogging?')
		return Conversions.str_to_bool(response)

	def set_eu_logging(self, ext_uci_log: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:EULogging \n
		Snippet: driver.source.bb.eutra.logGen.uplink.set_eu_logging(ext_uci_log = False) \n
		Enables the generation of a logfile with extended information regarding the DCI/UCI mapping. \n
			:param ext_uci_log: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(ext_uci_log)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:EULogging {param}')

	def get_prach(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:PRACh \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.uplink.get_prach() \n
		No command help available \n
			:return: prach_log_state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:PRACh?')
		return Conversions.str_to_bool(response)

	def set_prach(self, prach_log_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:PRACh \n
		Snippet: driver.source.bb.eutra.logGen.uplink.set_prach(prach_log_state = False) \n
		No command help available \n
			:param prach_log_state: No help available
		"""
		param = Conversions.bool_to_str(prach_log_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:PRACh {param}')

	def get_pucch(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:PUCCh \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.uplink.get_pucch() \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:return: pucch_log_state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:PUCCh?')
		return Conversions.str_to_bool(response)

	def set_pucch(self, pucch_log_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:PUCCh \n
		Snippet: driver.source.bb.eutra.logGen.uplink.set_pucch(pucch_log_state = False) \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:param pucch_log_state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(pucch_log_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:PUCCh {param}')

	def get_pucdrs(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:PUCDrs \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.uplink.get_pucdrs() \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:return: pusch_drs_log: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:PUCDrs?')
		return Conversions.str_to_bool(response)

	def set_pucdrs(self, pusch_drs_log: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:PUCDrs \n
		Snippet: driver.source.bb.eutra.logGen.uplink.set_pucdrs(pusch_drs_log = False) \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:param pusch_drs_log: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(pusch_drs_log)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:PUCDrs {param}')

	def get_pusch(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:PUSCh \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.uplink.get_pusch() \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:return: pusch_log_state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:PUSCh?')
		return Conversions.str_to_bool(response)

	def set_pusch(self, pusch_log_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:PUSCh \n
		Snippet: driver.source.bb.eutra.logGen.uplink.set_pusch(pusch_log_state = False) \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:param pusch_log_state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(pusch_log_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:PUSCh {param}')

	def get_pusdrs(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:PUSDrs \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.uplink.get_pusdrs() \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:return: pusch_drs_log: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:PUSDrs?')
		return Conversions.str_to_bool(response)

	def set_pusdrs(self, pusch_drs_log: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:PUSDrs \n
		Snippet: driver.source.bb.eutra.logGen.uplink.set_pusdrs(pusch_drs_log = False) \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:param pusch_drs_log: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(pusch_drs_log)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:PUSDrs {param}')

	def get_sl(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:SL \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.uplink.get_sl() \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:return: log_sidelink: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:SL?')
		return Conversions.str_to_bool(response)

	def set_sl(self, log_sidelink: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:SL \n
		Snippet: driver.source.bb.eutra.logGen.uplink.set_sl(log_sidelink = False) \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:param log_sidelink: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(log_sidelink)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:SL {param}')

	def get_sld(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:SLD \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.uplink.get_sld() \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:return: log_sidelink_drs: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:SLD?')
		return Conversions.str_to_bool(response)

	def set_sld(self, log_sidelink_drs: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:SLD \n
		Snippet: driver.source.bb.eutra.logGen.uplink.set_sld(log_sidelink_drs = False) \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:param log_sidelink_drs: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(log_sidelink_drs)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:SLD {param}')

	def get_srs(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:SRS \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.uplink.get_srs() \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:return: srs_state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:SRS?')
		return Conversions.str_to_bool(response)

	def set_srs(self, srs_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:UL:SRS \n
		Snippet: driver.source.bb.eutra.logGen.uplink.set_srs(srs_state = False) \n
		Enables the channel or reference signal for that logfiles are generated. \n
			:param srs_state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(srs_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:UL:SRS {param}')

	def clone(self) -> 'Uplink':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Uplink(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Aone:
	"""Aone commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("aone", core, parent)

	def get_unscaled(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:CONVersion:GALileo:UTC:AONE:UNSCaled \n
		Snippet: value: float = driver.source.bb.gnss.time.conversion.galileo.utc.aone.get_unscaled() \n
		Sets the first order term of polynomial, A1. \n
			:return: a_1: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:TIME:CONVersion:GALileo:UTC:AONE:UNSCaled?')
		return Conversions.str_to_float(response)

	def set_unscaled(self, a_1: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:CONVersion:GALileo:UTC:AONE:UNSCaled \n
		Snippet: driver.source.bb.gnss.time.conversion.galileo.utc.aone.set_unscaled(a_1 = 1.0) \n
		Sets the first order term of polynomial, A1. \n
			:param a_1: integer Range: -8388608 to 8388607
		"""
		param = Conversions.decimal_value_to_str(a_1)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:TIME:CONVersion:GALileo:UTC:AONE:UNSCaled {param}')

	def get_value(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:CONVersion:GALileo:UTC:AONE \n
		Snippet: value: int = driver.source.bb.gnss.time.conversion.galileo.utc.aone.get_value() \n
		Sets the first order term of polynomial, A1. \n
			:return: aone: integer Range: -8388608 to 8388607
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:TIME:CONVersion:GALileo:UTC:AONE?')
		return Conversions.str_to_int(response)

	def set_value(self, aone: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:CONVersion:GALileo:UTC:AONE \n
		Snippet: driver.source.bb.gnss.time.conversion.galileo.utc.aone.set_value(aone = 1) \n
		Sets the first order term of polynomial, A1. \n
			:param aone: integer Range: -8388608 to 8388607
		"""
		param = Conversions.decimal_value_to_str(aone)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:TIME:CONVersion:GALileo:UTC:AONE {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Trigger:
	"""Trigger commands group definition. 14 total commands, 3 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("trigger", core, parent)

	@property
	def external(self):
		"""external commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_external'):
			from .External import External
			self._external = External(self._core, self._base)
		return self._external

	@property
	def obaseband(self):
		"""obaseband commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_obaseband'):
			from .Obaseband import Obaseband
			self._obaseband = Obaseband(self._core, self._base)
		return self._obaseband

	@property
	def output(self):
		"""output commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_output'):
			from .Output import Output
			self._output = Output(self._core, self._base)
		return self._output

	def get_slength(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:SIRius:TERRestrial:TRIGger:SLENgth \n
		Snippet: value: int = driver.source.bb.sirius.terrestrial.trigger.get_slength() \n
		No command help available \n
			:return: slength: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:SIRius:TERRestrial:TRIGger:SLENgth?')
		return Conversions.str_to_int(response)

	def set_slength(self, slength: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:SIRius:TERRestrial:TRIGger:SLENgth \n
		Snippet: driver.source.bb.sirius.terrestrial.trigger.set_slength(slength = 1) \n
		No command help available \n
			:param slength: No help available
		"""
		param = Conversions.decimal_value_to_str(slength)
		self._core.io.write(f'SOURce<HwInstance>:BB:SIRius:TERRestrial:TRIGger:SLENgth {param}')

	# noinspection PyTypeChecker
	def get_source(self) -> enums.TriggerSourceC:
		"""SCPI: [SOURce<HW>]:BB:SIRius:TERRestrial:TRIGger:SOURce \n
		Snippet: value: enums.TriggerSourceC = driver.source.bb.sirius.terrestrial.trigger.get_source() \n
		No command help available \n
			:return: source: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:SIRius:TERRestrial:TRIGger:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.TriggerSourceC)

	def set_source(self, source: enums.TriggerSourceC) -> None:
		"""SCPI: [SOURce<HW>]:BB:SIRius:TERRestrial:TRIGger:SOURce \n
		Snippet: driver.source.bb.sirius.terrestrial.trigger.set_source(source = enums.TriggerSourceC.BBSY) \n
		No command help available \n
			:param source: No help available
		"""
		param = Conversions.enum_scalar_to_str(source, enums.TriggerSourceC)
		self._core.io.write(f'SOURce<HwInstance>:BB:SIRius:TERRestrial:TRIGger:SOURce {param}')

	# noinspection PyTypeChecker
	def get_sequence(self) -> enums.DmTrigMode:
		"""SCPI: [SOURce<HW>]:BB:SIRius:TERRestrial:[TRIGger]:SEQuence \n
		Snippet: value: enums.DmTrigMode = driver.source.bb.sirius.terrestrial.trigger.get_sequence() \n
		No command help available \n
			:return: sequence: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:SIRius:TERRestrial:TRIGger:SEQuence?')
		return Conversions.str_to_scalar_enum(response, enums.DmTrigMode)

	def set_sequence(self, sequence: enums.DmTrigMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:SIRius:TERRestrial:[TRIGger]:SEQuence \n
		Snippet: driver.source.bb.sirius.terrestrial.trigger.set_sequence(sequence = enums.DmTrigMode.AAUTo) \n
		No command help available \n
			:param sequence: No help available
		"""
		param = Conversions.enum_scalar_to_str(sequence, enums.DmTrigMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:SIRius:TERRestrial:TRIGger:SEQuence {param}')

	def clone(self) -> 'Trigger':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Trigger(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pwr:
	"""Pwr commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pwr", core, parent)

	def set(self, power: float, userNull=repcap.UserNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:OFDM:USER<CH0>:PWR \n
		Snippet: driver.source.bb.ofdm.user.pwr.set(power = 1.0, userNull = repcap.UserNull.Default) \n
		Applies a power offset. \n
			:param power: float Range: -80 to 10
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')"""
		param = Conversions.decimal_value_to_str(power)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:OFDM:USER{userNull_cmd_val}:PWR {param}')

	def get(self, userNull=repcap.UserNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:OFDM:USER<CH0>:PWR \n
		Snippet: value: float = driver.source.bb.ofdm.user.pwr.get(userNull = repcap.UserNull.Default) \n
		Applies a power offset. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:return: power: float Range: -80 to 10"""
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:OFDM:USER{userNull_cmd_val}:PWR?')
		return Conversions.str_to_float(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal.RepeatedCapability import RepeatedCapability
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Set:
	"""Set commands group definition. 18 total commands, 2 Sub-groups, 0 group commands
	Repeated Capability: ResourceSetNull, default value after init: ResourceSetNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("set", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_resourceSetNull_get', 'repcap_resourceSetNull_set', repcap.ResourceSetNull.Nr0)

	def repcap_resourceSetNull_set(self, enum_value: repcap.ResourceSetNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to ResourceSetNull.Default
		Default value after init: ResourceSetNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_resourceSetNull_get(self) -> repcap.ResourceSetNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def nresources(self):
		"""nresources commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nresources'):
			from .Nresources import Nresources
			self._nresources = Nresources(self._core, self._base)
		return self._nresources

	@property
	def res(self):
		"""res commands group. 14 Sub-classes, 0 commands."""
		if not hasattr(self, '_res'):
			from .Res import Res
			self._res = Res(self._core, self._base)
		return self._res

	def clone(self) -> 'Set':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Set(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Angle:
	"""Angle commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("angle", core, parent)

	def get_climb(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:ANGLe:CLIMb \n
		Snippet: value: float = driver.source.fsimulator.dsSimulation.towerToAir.angle.get_climb() \n
		No command help available \n
			:return: angle_climb: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:ANGLe:CLIMb?')
		return Conversions.str_to_float(response)

	def set_climb(self, angle_climb: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:ANGLe:CLIMb \n
		Snippet: driver.source.fsimulator.dsSimulation.towerToAir.angle.set_climb(angle_climb = 1.0) \n
		No command help available \n
			:param angle_climb: No help available
		"""
		param = Conversions.decimal_value_to_str(angle_climb)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:ANGLe:CLIMb {param}')

	def get_descent(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:ANGLe:DESCent \n
		Snippet: value: float = driver.source.fsimulator.dsSimulation.towerToAir.angle.get_descent() \n
		No command help available \n
			:return: angle_descent: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:ANGLe:DESCent?')
		return Conversions.str_to_float(response)

	def set_descent(self, angle_descent: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:TOWertoair:ANGLe:DESCent \n
		Snippet: driver.source.fsimulator.dsSimulation.towerToAir.angle.set_descent(angle_descent = 1.0) \n
		No command help available \n
			:param angle_descent: No help available
		"""
		param = Conversions.decimal_value_to_str(angle_descent)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:TOWertoair:ANGLe:DESCent {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Siso:
	"""Siso commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("siso", core, parent)

	# noinspection PyTypeChecker
	def get_copy(self) -> enums.FadCopyHwdEst:
		"""SCPI: [SOURce<HW>]:FSIMulator:SISO:COPY \n
		Snippet: value: enums.FadCopyHwdEst = driver.source.fsimulator.siso.get_copy() \n
		In 'System Configurations' with multiple entities (L > 2) , copies the settings of the current fading simulator to all or
		to the selected entities. \n
			:return: copy_to_dest: FADB| FADA| FADC| FADD| FADF| FADE| FADG| FADH| ALL
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:SISO:COPY?')
		return Conversions.str_to_scalar_enum(response, enums.FadCopyHwdEst)

	def set_copy(self, copy_to_dest: enums.FadCopyHwdEst) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:SISO:COPY \n
		Snippet: driver.source.fsimulator.siso.set_copy(copy_to_dest = enums.FadCopyHwdEst.ALL) \n
		In 'System Configurations' with multiple entities (L > 2) , copies the settings of the current fading simulator to all or
		to the selected entities. \n
			:param copy_to_dest: FADB| FADA| FADC| FADD| FADF| FADE| FADG| FADH| ALL
		"""
		param = Conversions.enum_scalar_to_str(copy_to_dest, enums.FadCopyHwdEst)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:SISO:COPY {param}')



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import enums
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BbSet1:
	"""BbSet1 commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bbSet1", core, parent)

	def set(self, dl_bwp_bundle_set_1: enums.PrbBundleSizeSet1, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<CH0>:CELL<ST0>:DL:BWP<DIR0>:PDSCh:PREC:BBSet1 \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.prec.bbSet1.set(dl_bwp_bundle_set_1 = enums.PrbBundleSizeSet1.N2WB, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Configures the dynamic PRB bundle type. Only available if 'Precoding' is enabled and 'Dynamic' is selected as 'PRB
		Bundling Type'. \n
			:param dl_bwp_bundle_set_1: N4| WIDeband| N2WB| N4WB N4 Default value. Dynamic PRB bundle size set 1 is set to N4. WIDeband Dynamic PRB bundle size set 1 is set to wideband. N2WB Dynamic PRB bundle size set 1 is set to N2-wideband. N4WB Dynamic PRB bundle size set 1 is set to N4-wideband.
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')"""
		param = Conversions.enum_scalar_to_str(dl_bwp_bundle_set_1, enums.PrbBundleSizeSet1)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._base.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:PREC:BBSet1 {param}')

	# noinspection PyTypeChecker
	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> enums.PrbBundleSizeSet1:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<CH0>:CELL<ST0>:DL:BWP<DIR0>:PDSCh:PREC:BBSet1 \n
		Snippet: value: enums.PrbBundleSizeSet1 = driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.prec.bbSet1.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Configures the dynamic PRB bundle type. Only available if 'Precoding' is enabled and 'Dynamic' is selected as 'PRB
		Bundling Type'. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:return: dl_bwp_bundle_set_1: N4| WIDeband| N2WB| N4WB N4 Default value. Dynamic PRB bundle size set 1 is set to N4. WIDeband Dynamic PRB bundle size set 1 is set to wideband. N2WB Dynamic PRB bundle size set 1 is set to N2-wideband. N4WB Dynamic PRB bundle size set 1 is set to N4-wideband."""
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._base.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:PREC:BBSet1?')
		return Conversions.str_to_scalar_enum(response, enums.PrbBundleSizeSet1)



from typing import List

from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal.Types import DataType
from .............Internal.StructBase import StructBase
from .............Internal.ArgStruct import ArgStruct
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ci16:
	"""Ci16 commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ci16", core, parent)

	# noinspection PyTypeChecker
	class Ci16Struct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Pattern: List[str]: 7 bits Bit pattern for the cancellation indication.
			- Bitcount: int: integer Range: 1 to 7"""
		__meta_args_list = [
			ArgStruct('Pattern', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: List[str] = None
			self.Bitcount: int = None

	def set(self, structure: Ci16Struct, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default, indexNull=repcap.IndexNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CH0>:SUBF<ST0>:USER<DIR0>:BWPart<GR0>:ALLoc<USER0>:CS:DCI<S2US0>:CI16 \n
		Snippet: driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.cs.dci.ci16.set(value = [PROPERTY_STRUCT_NAME](), cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the cancellation indication parameters for the DCI format 2_4. \n
			:param structure: for set value, see the help for Ci16Struct structure arguments.
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Dci')"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._base.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		indexNull_cmd_val = self._base.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		self._core.io.write_struct(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CS:DCI{indexNull_cmd_val}:CI16', structure)

	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default, indexNull=repcap.IndexNull.Default) -> Ci16Struct:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CH0>:SUBF<ST0>:USER<DIR0>:BWPart<GR0>:ALLoc<USER0>:CS:DCI<S2US0>:CI16 \n
		Snippet: value: Ci16Struct = driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.cs.dci.ci16.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the cancellation indication parameters for the DCI format 2_4. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Dci')
			:return: structure: for return value, see the help for Ci16Struct structure arguments."""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._base.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		indexNull_cmd_val = self._base.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CS:DCI{indexNull_cmd_val}:CI16?', self.__class__.Ci16Struct())



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tmodel:
	"""Tmodel commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tmodel", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:SETTing:TMODel:CATalog \n
		Snippet: value: List[str] = driver.source.bb.tdscdma.setting.tmodel.get_catalog() \n
		Queries the file with the test models defined in the TD-SCDMA standard or a self-defined test setup. \n
			:return: catalog: filename1,filename2,... Returns a string of filenames separated by commas.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TDSCdma:SETTing:TMODel:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_value(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:SETTing:TMODel \n
		Snippet: value: str = driver.source.bb.tdscdma.setting.tmodel.get_value() \n
		Selects the file with the test models defined in the TD-SCDMA standard or a self-defined test setup. \n
			:return: tmodel: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TDSCdma:SETTing:TMODel?')
		return trim_str_response(response)

	def set_value(self, tmodel: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:SETTing:TMODel \n
		Snippet: driver.source.bb.tdscdma.setting.tmodel.set_value(tmodel = '1') \n
		Selects the file with the test models defined in the TD-SCDMA standard or a self-defined test setup. \n
			:param tmodel: string
		"""
		param = Conversions.value_to_quoted_str(tmodel)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:SETTing:TMODel {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class User:
	"""User commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("user", core, parent)

	def set(self, scma_layer_user: enums.C5GscmaUser, allocationNull=repcap.AllocationNull.Default, layerNull=repcap.LayerNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:OFDM:ALLoc<CH0>:SCMA:LAYer<ST0>:USER \n
		Snippet: driver.source.bb.ofdm.alloc.scma.layer.user.set(scma_layer_user = enums.C5GscmaUser.USER0, allocationNull = repcap.AllocationNull.Default, layerNull = repcap.LayerNull.Default) \n
		Maps the users to the layers. \n
			:param scma_layer_user: USER0| USER1| USER2| USER3| USER4| USER5
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param layerNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Layer')"""
		param = Conversions.enum_scalar_to_str(scma_layer_user, enums.C5GscmaUser)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		layerNull_cmd_val = self._base.get_repcap_cmd_value(layerNull, repcap.LayerNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:OFDM:ALLoc{allocationNull_cmd_val}:SCMA:LAYer{layerNull_cmd_val}:USER {param}')

	# noinspection PyTypeChecker
	def get(self, allocationNull=repcap.AllocationNull.Default, layerNull=repcap.LayerNull.Default) -> enums.C5GscmaUser:
		"""SCPI: [SOURce<HW>]:BB:OFDM:ALLoc<CH0>:SCMA:LAYer<ST0>:USER \n
		Snippet: value: enums.C5GscmaUser = driver.source.bb.ofdm.alloc.scma.layer.user.get(allocationNull = repcap.AllocationNull.Default, layerNull = repcap.LayerNull.Default) \n
		Maps the users to the layers. \n
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param layerNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Layer')
			:return: scma_layer_user: USER0| USER1| USER2| USER3| USER4| USER5"""
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		layerNull_cmd_val = self._base.get_repcap_cmd_value(layerNull, repcap.LayerNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:OFDM:ALLoc{allocationNull_cmd_val}:SCMA:LAYer{layerNull_cmd_val}:USER?')
		return Conversions.str_to_scalar_enum(response, enums.C5GscmaUser)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Niot:
	"""Niot commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("niot", core, parent)

	def get_power(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:REFSig:NIOT:POWer \n
		Snippet: value: float = driver.source.bb.eutra.downlink.refsig.niot.get_power() \n
		Sets the power of the narrowband reference signal (NRS) . \n
			:return: nb_ref_sig_sym_powe: float Range: -80 to 10
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:REFSig:NIOT:POWer?')
		return Conversions.str_to_float(response)

	def set_power(self, nb_ref_sig_sym_powe: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:REFSig:NIOT:POWer \n
		Snippet: driver.source.bb.eutra.downlink.refsig.niot.set_power(nb_ref_sig_sym_powe = 1.0) \n
		Sets the power of the narrowband reference signal (NRS) . \n
			:param nb_ref_sig_sym_powe: float Range: -80 to 10
		"""
		param = Conversions.decimal_value_to_str(nb_ref_sig_sym_powe)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:REFSig:NIOT:POWer {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Direction:
	"""Direction commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("direction", core, parent)

	def set(self, direction: enums.ConnDirection, tmConnector=repcap.TmConnector.Default) -> None:
		"""SCPI: OUTPut<HW>:TM<CH>:DIRection \n
		Snippet: driver.output.tm.direction.set(direction = enums.ConnDirection.INPut, tmConnector = repcap.TmConnector.Default) \n
		Determines whether the connector is used as an input or an output. \n
			:param direction: INPut| OUTPut
			:param tmConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tm')"""
		param = Conversions.enum_scalar_to_str(direction, enums.ConnDirection)
		tmConnector_cmd_val = self._base.get_repcap_cmd_value(tmConnector, repcap.TmConnector)
		self._core.io.write(f'OUTPut<HwInstance>:TM{tmConnector_cmd_val}:DIRection {param}')

	# noinspection PyTypeChecker
	def get(self, tmConnector=repcap.TmConnector.Default) -> enums.ConnDirection:
		"""SCPI: OUTPut<HW>:TM<CH>:DIRection \n
		Snippet: value: enums.ConnDirection = driver.output.tm.direction.get(tmConnector = repcap.TmConnector.Default) \n
		Determines whether the connector is used as an input or an output. \n
			:param tmConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tm')
			:return: direction: INPut| OUTPut"""
		tmConnector_cmd_val = self._base.get_repcap_cmd_value(tmConnector, repcap.TmConnector)
		response = self._core.io.query_str(f'OUTPut<HwInstance>:TM{tmConnector_cmd_val}:DIRection?')
		return Conversions.str_to_scalar_enum(response, enums.ConnDirection)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dpch:
	"""Dpch commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dpch", core, parent)

	def get_count(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:PPARameter:DPCH:COUNt \n
		Snippet: value: int = driver.source.bb.tdscdma.down.pparameter.dpch.get_count() \n
		Sets the number of activated DPCHs. The maximum number depends on the spreading factor: Max. No. DPCH = 3 x 'Spreading
		Factor' \n
			:return: count: integer Range: 1 to 48
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TDSCdma:DOWN:PPARameter:DPCH:COUNt?')
		return Conversions.str_to_int(response)

	def set_count(self, count: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:PPARameter:DPCH:COUNt \n
		Snippet: driver.source.bb.tdscdma.down.pparameter.dpch.set_count(count = 1) \n
		Sets the number of activated DPCHs. The maximum number depends on the spreading factor: Max. No. DPCH = 3 x 'Spreading
		Factor' \n
			:param count: integer Range: 1 to 48
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:PPARameter:DPCH:COUNt {param}')

	# noinspection PyTypeChecker
	def get_crest(self) -> enums.CresFactMode:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:PPARameter:DPCH:CRESt \n
		Snippet: value: enums.CresFactMode = driver.source.bb.tdscdma.down.pparameter.dpch.get_crest() \n
		Selects the desired range for the crest factor of the test scenario. \n
			:return: crest: MINimum| AVERage| WORSt MINimum The crest factor is minimized. The channelization codes are distributed uniformly over the code domain. The timing offsets are increased by 3 per channel. AVERage An average crest factor is set. The channelization codes are distributed uniformly over the code domain. The timing offsets are all set to 0. WORSt The crest factor is set to an unfavorable value (i.e. maximum) . The channelization codes are assigned in ascending order. The timing offsets are all set to 0.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TDSCdma:DOWN:PPARameter:DPCH:CRESt?')
		return Conversions.str_to_scalar_enum(response, enums.CresFactMode)

	def set_crest(self, crest: enums.CresFactMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:PPARameter:DPCH:CRESt \n
		Snippet: driver.source.bb.tdscdma.down.pparameter.dpch.set_crest(crest = enums.CresFactMode.AVERage) \n
		Selects the desired range for the crest factor of the test scenario. \n
			:param crest: MINimum| AVERage| WORSt MINimum The crest factor is minimized. The channelization codes are distributed uniformly over the code domain. The timing offsets are increased by 3 per channel. AVERage An average crest factor is set. The channelization codes are distributed uniformly over the code domain. The timing offsets are all set to 0. WORSt The crest factor is set to an unfavorable value (i.e. maximum) . The channelization codes are assigned in ascending order. The timing offsets are all set to 0.
		"""
		param = Conversions.enum_scalar_to_str(crest, enums.CresFactMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:PPARameter:DPCH:CRESt {param}')

	# noinspection PyTypeChecker
	def get_sfactor(self) -> enums.TdscdmaSpreadFactor:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:PPARameter:DPCH:SFACtor \n
		Snippet: value: enums.TdscdmaSpreadFactor = driver.source.bb.tdscdma.down.pparameter.dpch.get_sfactor() \n
		Sets the spreading factor for the DPCHs. \n
			:return: sfactor: 1| 2| 4| 8| 16
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TDSCdma:DOWN:PPARameter:DPCH:SFACtor?')
		return Conversions.str_to_scalar_enum(response, enums.TdscdmaSpreadFactor)

	def set_sfactor(self, sfactor: enums.TdscdmaSpreadFactor) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:PPARameter:DPCH:SFACtor \n
		Snippet: driver.source.bb.tdscdma.down.pparameter.dpch.set_sfactor(sfactor = enums.TdscdmaSpreadFactor._1) \n
		Sets the spreading factor for the DPCHs. \n
			:param sfactor: 1| 2| 4| 8| 16
		"""
		param = Conversions.enum_scalar_to_str(sfactor, enums.TdscdmaSpreadFactor)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:PPARameter:DPCH:SFACtor {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rx:
	"""Rx commands group definition. 17 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rx", core, parent)

	@property
	def trajectory(self):
		"""trajectory commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_trajectory'):
			from .Trajectory import Trajectory
			self._trajectory = Trajectory(self._core, self._base)
		return self._trajectory

	@property
	def vehicle(self):
		"""vehicle commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_vehicle'):
			from .Vehicle import Vehicle
			self._vehicle = Vehicle(self._core, self._base)
		return self._vehicle

	def clone(self) -> 'Rx':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rx(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Icomponent:
	"""Icomponent commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("icomponent", core, parent)

	def get(self, frameBlock=repcap.FrameBlock.Default, row=repcap.Row.Default, column=repcap.Column.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:SMAPping:ROW<ST>:COL<DIR>:I \n
		Snippet: value: float = driver.source.bb.wlnn.fblock.smapping.row.col.icomponent.get(frameBlock = repcap.FrameBlock.Default, row = repcap.Row.Default, column = repcap.Column.Default) \n
		Queries the time shift value of element I of the selected row and column of the spatial transmit matrix. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param row: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Row')
			:param column: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Col')
			:return: ipart: float"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		row_cmd_val = self._base.get_repcap_cmd_value(row, repcap.Row)
		column_cmd_val = self._base.get_repcap_cmd_value(column, repcap.Column)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:SMAPping:ROW{row_cmd_val}:COL{column_cmd_val}:I?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.FbiMode, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:PCPCh:FBI:MODE \n
		Snippet: driver.source.bb.w3Gpp.mstation.pcpch.fbi.mode.set(mode = enums.FbiMode.D1B, mobileStation = repcap.MobileStation.Default) \n
		The command sets the number of bits (1 or 2) for the FBI field. With OFF, the field is not used.
			INTRO_CMD_HELP: The FBI pattern automatically sets the associated slot format: \n
			- FBI OFF = Slot format 0
			- FBI 1 bit = Slot format 1
			- FBI 2 bits = Slot format 2 \n
			:param mode: OFF| D1B| D2B
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')"""
		param = Conversions.enum_scalar_to_str(mode, enums.FbiMode)
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:PCPCh:FBI:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, mobileStation=repcap.MobileStation.Default) -> enums.FbiMode:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:PCPCh:FBI:MODE \n
		Snippet: value: enums.FbiMode = driver.source.bb.w3Gpp.mstation.pcpch.fbi.mode.get(mobileStation = repcap.MobileStation.Default) \n
		The command sets the number of bits (1 or 2) for the FBI field. With OFF, the field is not used.
			INTRO_CMD_HELP: The FBI pattern automatically sets the associated slot format: \n
			- FBI OFF = Slot format 0
			- FBI 1 bit = Slot format 1
			- FBI 2 bits = Slot format 2 \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: mode: OFF| D1B| D2B"""
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:PCPCh:FBI:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FbiMode)



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.Utilities import trim_str_response
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Time:
	"""Time commands group definition. 11 total commands, 3 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("time", core, parent)

	@property
	def daylightSavingTime(self):
		"""daylightSavingTime commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_daylightSavingTime'):
			from .DaylightSavingTime import DaylightSavingTime
			self._daylightSavingTime = DaylightSavingTime(self._core, self._base)
		return self._daylightSavingTime

	@property
	def hrTimer(self):
		"""hrTimer commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_hrTimer'):
			from .HrTimer import HrTimer
			self._hrTimer = HrTimer(self._core, self._base)
		return self._hrTimer

	@property
	def zone(self):
		"""zone commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_zone'):
			from .Zone import Zone
			self._zone = Zone(self._core, self._base)
		return self._zone

	def get_local(self) -> str:
		"""SCPI: SYSTem:TIME:LOCal \n
		Snippet: value: str = driver.system.time.get_local() \n
		No command help available \n
			:return: pseudo_string: No help available
		"""
		response = self._core.io.query_str('SYSTem:TIME:LOCal?')
		return trim_str_response(response)

	def set_local(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:TIME:LOCal \n
		Snippet: driver.system.time.set_local(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:TIME:LOCal {param}')

	def get_utc(self) -> str:
		"""SCPI: SYSTem:TIME:UTC \n
		Snippet: value: str = driver.system.time.get_utc() \n
		No command help available \n
			:return: pseudo_string: No help available
		"""
		response = self._core.io.query_str('SYSTem:TIME:UTC?')
		return trim_str_response(response)

	def set_utc(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:TIME:UTC \n
		Snippet: driver.system.time.set_utc(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:TIME:UTC {param}')

	# noinspection PyTypeChecker
	class ValueStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Hour: List[int]: integer Range: 0 to 23
			- Minute: int: integer Range: 0 to 59
			- Second: int: integer Range: 0 to 59"""
		__meta_args_list = [
			ArgStruct('Hour', DataType.IntegerList, None, False, True, 1),
			ArgStruct.scalar_int('Minute'),
			ArgStruct.scalar_int('Second')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Hour: List[int] = None
			self.Minute: int = None
			self.Second: int = None

	def get_value(self) -> ValueStruct:
		"""SCPI: SYSTem:TIME \n
		Snippet: value: ValueStruct = driver.system.time.get_value() \n
		Queries or sets the time for the instrument-internal clock. This is a password-protected function. Unlock the protection
		level 1 to access it. See SYSTem. \n
			:return: structure: for return value, see the help for ValueStruct structure arguments.
		"""
		return self._core.io.query_struct('SYSTem:TIME?', self.__class__.ValueStruct())

	def set_value(self, value: ValueStruct) -> None:
		"""SCPI: SYSTem:TIME \n
		Snippet: driver.system.time.set_value(value = ValueStruct()) \n
		Queries or sets the time for the instrument-internal clock. This is a password-protected function. Unlock the protection
		level 1 to access it. See SYSTem. \n
			:param value: see the help for ValueStruct structure arguments.
		"""
		self._core.io.write_struct('SYSTem:TIME', value)

	def clone(self) -> 'Time':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Time(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bmp:
	"""Bmp commands group definition. 5 total commands, 1 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bmp", core, parent)

	@property
	def valSubFrames(self):
		"""valSubFrames commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_valSubFrames'):
			from .ValSubFrames import ValSubFrames
			self._valSubFrames = ValSubFrames(self._core, self._base)
		return self._valSubFrames

	def get_pbchrep(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:BMP:PBCHrep \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.emtc.bmp.get_pbchrep() \n
		Configures the cell for PBCH repetition. \n
			:return: pbch_repetitions: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:BMP:PBCHrep?')
		return Conversions.str_to_bool(response)

	def set_pbchrep(self, pbch_repetitions: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:BMP:PBCHrep \n
		Snippet: driver.source.bb.eutra.downlink.emtc.bmp.set_pbchrep(pbch_repetitions = False) \n
		Configures the cell for PBCH repetition. \n
			:param pbch_repetitions: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(pbch_repetitions)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:BMP:PBCHrep {param}')

	def get_sibbr(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:BMP:SIBBr \n
		Snippet: value: int = driver.source.bb.eutra.downlink.emtc.bmp.get_sibbr() \n
		Sets the number of times the PDSCH allocation carrying the SIB1-BR is repeated. \n
			:return: sched_info_sib_1_br: integer Range: 0 to 18
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:BMP:SIBBr?')
		return Conversions.str_to_int(response)

	def set_sibbr(self, sched_info_sib_1_br: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:BMP:SIBBr \n
		Snippet: driver.source.bb.eutra.downlink.emtc.bmp.set_sibbr(sched_info_sib_1_br = 1) \n
		Sets the number of times the PDSCH allocation carrying the SIB1-BR is repeated. \n
			:param sched_info_sib_1_br: integer Range: 0 to 18
		"""
		param = Conversions.decimal_value_to_str(sched_info_sib_1_br)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:BMP:SIBBr {param}')

	# noinspection PyTypeChecker
	def get_start(self) -> enums.NumberA:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:BMP:STARt \n
		Snippet: value: enums.NumberA = driver.source.bb.eutra.downlink.emtc.bmp.get_start() \n
		Defines the first symbol within a frame that can be used for eMTC. \n
			:return: starting_symbol: 1| 2| 3| 4
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:BMP:STARt?')
		return Conversions.str_to_scalar_enum(response, enums.NumberA)

	def set_start(self, starting_symbol: enums.NumberA) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:BMP:STARt \n
		Snippet: driver.source.bb.eutra.downlink.emtc.bmp.set_start(starting_symbol = enums.NumberA._1) \n
		Defines the first symbol within a frame that can be used for eMTC. \n
			:param starting_symbol: 1| 2| 3| 4
		"""
		param = Conversions.enum_scalar_to_str(starting_symbol, enums.NumberA)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:BMP:STARt {param}')

	# noinspection PyTypeChecker
	def get_sub_frames(self) -> enums.EutraBitmap:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:BMP:SUBFrames \n
		Snippet: value: enums.EutraBitmap = driver.source.bb.eutra.downlink.emtc.bmp.get_sub_frames() \n
		Sets the valid subframes configuration over 10ms or 40ms. \n
			:return: bitmap_subframes: 10| 40
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:EMTC:BMP:SUBFrames?')
		return Conversions.str_to_scalar_enum(response, enums.EutraBitmap)

	def set_sub_frames(self, bitmap_subframes: enums.EutraBitmap) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:BMP:SUBFrames \n
		Snippet: driver.source.bb.eutra.downlink.emtc.bmp.set_sub_frames(bitmap_subframes = enums.EutraBitmap._10) \n
		Sets the valid subframes configuration over 10ms or 40ms. \n
			:param bitmap_subframes: 10| 40
		"""
		param = Conversions.enum_scalar_to_str(bitmap_subframes, enums.EutraBitmap)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:BMP:SUBFrames {param}')

	def clone(self) -> 'Bmp':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Bmp(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cosine:
	"""Cosine commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cosine", core, parent)

	def get_cofs(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:DAB:FILTer:PARameter:COSine:COFS \n
		Snippet: value: float = driver.source.bb.dab.filterPy.parameter.cosine.get_cofs() \n
		No command help available \n
			:return: cofs: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DAB:FILTer:PARameter:COSine:COFS?')
		return Conversions.str_to_float(response)

	def set_cofs(self, cofs: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:DAB:FILTer:PARameter:COSine:COFS \n
		Snippet: driver.source.bb.dab.filterPy.parameter.cosine.set_cofs(cofs = 1.0) \n
		No command help available \n
			:param cofs: No help available
		"""
		param = Conversions.decimal_value_to_str(cofs)
		self._core.io.write(f'SOURce<HwInstance>:BB:DAB:FILTer:PARameter:COSine:COFS {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:DAB:FILTer:PARameter:COSine \n
		Snippet: value: float = driver.source.bb.dab.filterPy.parameter.cosine.get_value() \n
		No command help available \n
			:return: cosine: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DAB:FILTer:PARameter:COSine?')
		return Conversions.str_to_float(response)

	def set_value(self, cosine: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:DAB:FILTer:PARameter:COSine \n
		Snippet: driver.source.bb.dab.filterPy.parameter.cosine.set_value(cosine = 1.0) \n
		No command help available \n
			:param cosine: No help available
		"""
		param = Conversions.decimal_value_to_str(cosine)
		self._core.io.write(f'SOURce<HwInstance>:BB:DAB:FILTer:PARameter:COSine {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Profile:
	"""Profile commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("profile", core, parent)

	def set(self, profile: enums.FadingProfileA, fadingGroup=repcap.FadingGroup.Default, path=repcap.Path.Default) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DELay:GROup<ST>:PATH<CH>:PROFile \n
		Snippet: driver.source.fsimulator.delay.group.path.profile.set(profile = enums.FadingProfileA.BELLindoor, fadingGroup = repcap.FadingGroup.Default, path = repcap.Path.Default) \n
		Selects the fading profile for the paths. \n
			:param profile: SPATh| RAYLeigh| PDOPpler| RICE| CPHase| OGAUs| TGAUs| DGAUs| WDOPpler| WRICe| GDOPpler| GFD8| GFD1| WATTerson| CUSTom| SCM | BELLindoor| BELVehicle SPAT static transmission path PDOPpler | RAYLeigh | RICE | CUSTom | SCM pure Doppler | Rayleigh | Rice | Custom | SCM CPHase constant phase OGAUs | TGAUs | DGAUs | GDOPpler | GFD8 | GFD1 GAUS1 | GAUS2 | GAUSDAB | Gauss Doppler | Gauss (0.08 fd) | Gauss (0.01 fd) WATTerson Gauss (Watterson) WDOPpler | WRICe WiMAX Doppler | WiMAX Rice BELLindoor|BELVehicle Bell Shape tgn Indoor, Bell Shape tgn Moving Vehicle
			:param fadingGroup: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Group')
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Path')"""
		param = Conversions.enum_scalar_to_str(profile, enums.FadingProfileA)
		fadingGroup_cmd_val = self._base.get_repcap_cmd_value(fadingGroup, repcap.FadingGroup)
		path_cmd_val = self._base.get_repcap_cmd_value(path, repcap.Path)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DELay:GROup{fadingGroup_cmd_val}:PATH{path_cmd_val}:PROFile {param}')

	# noinspection PyTypeChecker
	def get(self, fadingGroup=repcap.FadingGroup.Default, path=repcap.Path.Default) -> enums.FadingProfileA:
		"""SCPI: [SOURce<HW>]:FSIMulator:DELay:GROup<ST>:PATH<CH>:PROFile \n
		Snippet: value: enums.FadingProfileA = driver.source.fsimulator.delay.group.path.profile.get(fadingGroup = repcap.FadingGroup.Default, path = repcap.Path.Default) \n
		Selects the fading profile for the paths. \n
			:param fadingGroup: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Group')
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Path')
			:return: profile: SPATh| RAYLeigh| PDOPpler| RICE| CPHase| OGAUs| TGAUs| DGAUs| WDOPpler| WRICe| GDOPpler| GFD8| GFD1| WATTerson| CUSTom| SCM | BELLindoor| BELVehicle SPAT static transmission path PDOPpler | RAYLeigh | RICE | CUSTom | SCM pure Doppler | Rayleigh | Rice | Custom | SCM CPHase constant phase OGAUs | TGAUs | DGAUs | GDOPpler | GFD8 | GFD1 GAUS1 | GAUS2 | GAUSDAB | Gauss Doppler | Gauss (0.08 fd) | Gauss (0.01 fd) WATTerson Gauss (Watterson) WDOPpler | WRICe WiMAX Doppler | WiMAX Rice BELLindoor|BELVehicle Bell Shape tgn Indoor, Bell Shape tgn Moving Vehicle"""
		fadingGroup_cmd_val = self._base.get_repcap_cmd_value(fadingGroup, repcap.FadingGroup)
		path_cmd_val = self._base.get_repcap_cmd_value(path, repcap.Path)
		response = self._core.io.query_str(f'SOURce<HwInstance>:FSIMulator:DELay:GROup{fadingGroup_cmd_val}:PATH{path_cmd_val}:PROFile?')
		return Conversions.str_to_scalar_enum(response, enums.FadingProfileA)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dshape:
	"""Dshape commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dshape", core, parent)

	def set(self, doppler_shape: enums.FadProfCustRange, fadingGroup=repcap.FadingGroup.Default, path=repcap.Path.Default) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DEL:GROup<ST>:PATH<CH>:CUSTom:DSHape \n
		Snippet: driver.source.fsimulator.delPy.group.path.custom.dshape.set(doppler_shape = enums.FadProfCustRange.FLAT, fadingGroup = repcap.FadingGroup.Default, path = repcap.Path.Default) \n
		Sets the doppler shape of the virtual profile. \n
			:param doppler_shape: FLAT| RAYLeigh
			:param fadingGroup: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Group')
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Path')"""
		param = Conversions.enum_scalar_to_str(doppler_shape, enums.FadProfCustRange)
		fadingGroup_cmd_val = self._base.get_repcap_cmd_value(fadingGroup, repcap.FadingGroup)
		path_cmd_val = self._base.get_repcap_cmd_value(path, repcap.Path)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DEL:GROup{fadingGroup_cmd_val}:PATH{path_cmd_val}:CUSTom:DSHape {param}')

	# noinspection PyTypeChecker
	def get(self, fadingGroup=repcap.FadingGroup.Default, path=repcap.Path.Default) -> enums.FadProfCustRange:
		"""SCPI: [SOURce<HW>]:FSIMulator:DEL:GROup<ST>:PATH<CH>:CUSTom:DSHape \n
		Snippet: value: enums.FadProfCustRange = driver.source.fsimulator.delPy.group.path.custom.dshape.get(fadingGroup = repcap.FadingGroup.Default, path = repcap.Path.Default) \n
		Sets the doppler shape of the virtual profile. \n
			:param fadingGroup: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Group')
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Path')
			:return: doppler_shape: FLAT| RAYLeigh"""
		fadingGroup_cmd_val = self._base.get_repcap_cmd_value(fadingGroup, repcap.FadingGroup)
		path_cmd_val = self._base.get_repcap_cmd_value(path, repcap.Path)
		response = self._core.io.query_str(f'SOURce<HwInstance>:FSIMulator:DEL:GROup{fadingGroup_cmd_val}:PATH{path_cmd_val}:CUSTom:DSHape?')
		return Conversions.str_to_scalar_enum(response, enums.FadProfCustRange)
